``Spool`` Module
=================

The ``spool`` user interface is written in ``Qt4`` (using ``pyside``), the plots are generated through ``pyqtgraph`` (http://www.pyqtgraph.org).

.. automodule:: kite.spool
    :members:
    :undoc-members:
